@@ -135,7 +135,8 @@ class MMDetWandbHook(WandbLoggerHook):
         super(MMDetWandbHook, self).before_run(runner)
 
         # Save and Log config.
-        if runner.meta is not None:
+        if runner.meta is not None and runner.meta.get('exp_name',
+                                                       None) is not None:
             src_cfg_path = osp.join(runner.work_dir,
                                     runner.meta.get('exp_name', None))
             if osp.exists(src_cfg_path):
@@ -565,10 +566,12 @@ class MMDetWandbHook(WandbLoggerHook):
         data_artifact = self.wandb.Artifact('val', type='dataset')
         data_artifact.add(self.data_table, 'val_data')
 
-        self.wandb.run.use_artifact(data_artifact)
-        data_artifact.wait()
-
-        self.data_table_ref = data_artifact.get('val_data')
+        if not self.wandb.run.offline:
+            self.wandb.run.use_artifact(data_artifact)
+            data_artifact.wait()
+            self.data_table_ref = data_artifact.get('val_data')
+        else:
+            self.data_table_ref = self.data_table
 
     def _log_eval_table(self, idx):
         """Log the W&B Tables for model evaluation.
