@@ -6,7 +6,8 @@ from mmcv.cnn import VGG
 from mmcv.runner.hooks import HOOKS, Hook
 
 from mmdet.datasets.builder import PIPELINES
-from mmdet.datasets.pipelines import LoadAnnotations, LoadImageFromFile
+from mmdet.datasets.pipelines import (LoadAnnotations, LoadImageFromFile,
+                                      LoadPanopticAnnotations)
 from mmdet.models.dense_heads import GARPNHead, RPNHead
 from mmdet.models.roi_heads.mask_heads import FusedSemanticHead
 
@@ -104,7 +105,8 @@ def get_loading_pipeline(pipeline):
         obj_cls = PIPELINES.get(cfg['type'])
         # TODO：use more elegant way to distinguish loading modules
         if obj_cls is not None and obj_cls in (LoadImageFromFile,
-                                               LoadAnnotations):
+                                               LoadAnnotations,
+                                               LoadPanopticAnnotations):
             loading_pipeline_cfg.append(cfg)
     assert len(loading_pipeline_cfg) == 2, \
         'The data pipeline in your config file must include ' \
